@@ -14,12 +14,15 @@
 """
 
 import os
+import datetime
 
 if __name__ == "__main__":
     # run all unittest directly
     os.environ['DJANGO_SETTINGS_MODULE'] = "pylucid_project.settings"
 
 from django.conf import settings
+from django.contrib.messages import constants as message_constants
+from django.core.cache import cache
 from django.core.urlresolvers import reverse
 from django.test.client import Client
 
@@ -28,13 +31,21 @@ from django_tools.unittest_utils.BrowserDebug import debug_response
 from pylucid_project.tests.test_tools import basetest
 from pylucid_project.apps.pylucid.markup import MARKUP_CREOLE
 
-from pylucid_project.pylucid_plugins.blog.models import BlogEntry
+from blog.models import DEBUG_LANG_FILTER, BlogEntry
+from blog.preference_forms import BlogPrefForm
 
 
 SUMMARY_URL = "/%s/blog/"
+TAG_URL = "/%s/blog/tags/%s/"
 CREATE_URL = "/pylucid_admin/plugins/blog/new_blog_entry/"
+EDIT_URL = "/pylucid_admin/plugins/blog/edit/%i/"
+TRANSLATE_URL = "/pylucid_admin/plugins/blog/translate/%i/"
 ENTRY_URL = "/%s/blog/detail/PyLucid CMS/"
 ADD_PERMISSION = "blog.add_blogentry"
+BLOG_UNITTEST_FIXTURES = os.path.join(settings.PYLUCID_BASE_PATH, "pylucid_plugins", "blog", "test_fixtures.json")
+
+TODAY_URL_PART = datetime.date.today().strftime("%Y/%m/%d")
+TEST_DATE = "2000/01/24" # Date in test fixtures
 
 
 class BlogPluginTestCase(basetest.BaseLanguageTestCase):
@@ -50,14 +61,47 @@ class BlogPluginTestCase(basetest.BaseLanguageTestCase):
         - self.other_language - alternative Language mode instance (default: de instance)
         - assertContentLanguage() - Check if response is in right language
     """
-    SUMMARY_MUST_CONTAIN_EN = (
+    def _pre_setup(self, *args, **kwargs):
+        self.fixtures.append(BLOG_UNITTEST_FIXTURES)
+        super(BlogPluginTestCase, self)._pre_setup(*args, **kwargs)
+        settings.DEBUG = False
+
+    # existing english entries from test fixtures:
+    FIRST_ENTRY = (
+        "First entry in english",
+        "/en/blog/%s/first-entry-in-english/" % TEST_DATE,
+        "<p>1. <strong>blog article</strong> in <i>english</i>!</p>",
+    )
+    SECOND_ENTRY = (
+        "Second entry only in english",
+        "/en/blog/%s/second-entry-only-in-english/" % TEST_DATE,
+        "<p>2. <strong>blog article</strong> only in <i>english</i>!</p>",
+    )
+
+    # existing german entries from test fixtures:
+    ERSTER_EINTRAG = (
+        "Erster Eintrag in deutsch",
+        "/de/blog/%s/erster-eintrag-in-deutsch/" % TEST_DATE,
+        "<p>1. <strong>Blog Artikel</strong> in <i>deutsch</i>!</p>"
+    )
+    DRITTER_EINTRAG = (
+        "Dritter Eintrag nur in deutsch",
+        "/de/blog/%s/dritter-eintrag-nur-in-deutsch/" % TEST_DATE,
+        "<p>3. <strong>Blog Artikel</strong> nur in <i>deutsch</i>!</p>"
+    )
+
+    SUMMARY_EN_CONTAINS = (
         '<a href="/en/blog/" title="Your personal weblog.">blog</a>',
-        '<a href="/en/blog/">All articles in English.</a>',
+        '<a href="/en/blog/">All articles.</a>',
+        "comments for 'blog':", "Leave a comment</a>", # from pylucid comments
+
     )
-    SUMMARY_MUST_CONTAIN_DE = (
+    SUMMARY_DE_CONTAINS = (
         '<a href="/de/blog/" title="Dein eigener Weblog.">blog</a>',
-        '<a href="/de/blog/">Alle Artikel in Deutsch.</a>',
+        '<a href="/de/blog/">Alle Artikel.</a>',
+        "Kommentare für 'blog':", "Kommentar hinterlassen</a>", # from pylucid comments
     )
+
     ENTRY_MUST_CONTAIN_EN = (
         '<a href="/en/blog/detail/PyLucid CMS/" title="PyLucid CMS', # breadcrumbs
         '<dd>PyLucid CMS</dd>',
@@ -73,17 +117,24 @@ class BlogPluginTestCase(basetest.BaseLanguageTestCase):
         'Leave a comment</a>', # from pylucid comments
     )
 
-    def assertBlogPage(self, response, must_contain):
+    def assertBlogPage(self, response, language, must_contain, must_not_contain):
         self.failUnlessEqual(response.status_code, 200)
         self.assertResponse(response, must_contain=must_contain,
-            must_not_contain=("Traceback", "XXX INVALID TEMPLATE STRING")
+            must_not_contain=must_not_contain + ("Traceback", "XXX INVALID TEMPLATE STRING")
         )
+        self.assertContentLanguage(response, language)
 
-    def assertSummaryEN(self, response):
-        self.assertBlogPage(response, must_contain=self.SUMMARY_MUST_CONTAIN_EN)
-
-    def assertSummaryDE(self, response):
-        self.assertBlogPage(response, must_contain=self.SUMMARY_MUST_CONTAIN_DE)
+#    def assertSummaryEN(self, response):
+#        self.assertBlogPage(response,
+#            must_contain=self.SUMMARY_MUST_CONTAIN_EN,
+#            must_not_contain=self.SUMMARY_MUST_NOT_CONTAIN_EN,
+#        )
+#
+#    def assertSummaryDE(self, response):
+#        self.assertBlogPage(response,
+#            must_contain=self.SUMMARY_MUST_CONTAIN_DE,
+#            must_not_contain=self.SUMMARY_MUST_NOT_CONTAIN_DE,
+#        )
 
     def assertEntryEN(self, response):
         self.assertBlogPage(response, must_contain=self.ENTRY_MUST_CONTAIN_EN)
@@ -96,15 +147,100 @@ class BlogPluginTestCase(basetest.BaseLanguageTestCase):
         return self.login_with_permissions(usertype="normal", permissions=(ADD_PERMISSION,))
 
 
+
 class BlogPluginAnonymousTest(BlogPluginTestCase):
-    def test_summary_en(self):
+    """
+    ALL_LANGUAGES - "Don't filter by languages. Allways display all blog entries."
+    PREFERED_LANGUAGES - "Filter by client prefered languages (set in browser and send by HTTP_ACCEPT_LANGUAGE header)"
+    CURRENT_LANGUAGE - "Display only blog entries in current language (select on the page)"
+    """
+
+    def setUp(self):
+        cache.clear()
+
+        from pylucid_project.apps.pylucid.preference_forms import SystemPreferencesForm
+        system_preferences = SystemPreferencesForm()
+        system_preferences["message_level_anonymous"] = message_constants.DEBUG
+        system_preferences.save()
+        DEBUG_LANG_FILTER = True
+        settings.PYLUCID.I18N_DEBUG = True
+
+
+    def _set_language_filter(self, language_filter):
+        self.pref_form = BlogPrefForm()
+        self.pref_form["language_filter"] = language_filter
+        self.pref_form.save()
+
+    def test_summary_en_all_languages(self):
+        self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
+
         response = self.client.get(
             SUMMARY_URL % self.default_language.code,
             HTTP_ACCEPT_LANGUAGE=self.default_language.code,
         )
-        self.assertSummaryEN(response)
-        self.assertContentLanguage(response, self.default_language)
+        self.assertBlogPage(response, self.default_language,
+            must_contain=self.SUMMARY_EN_CONTAINS + self.FIRST_ENTRY + self.SECOND_ENTRY + self.DRITTER_EINTRAG,
+            must_not_contain=self.SUMMARY_DE_CONTAINS + self.ERSTER_EINTRAG,
+        )
 
+    def test_summary_en_current_languages(self):
+        self._set_language_filter(BlogPrefForm.CURRENT_LANGUAGE)
+
+        response = self.client.get(
+            SUMMARY_URL % self.default_language.code,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertBlogPage(response, self.default_language,
+            must_contain=self.SUMMARY_EN_CONTAINS + self.FIRST_ENTRY + self.SECOND_ENTRY,
+            must_not_contain=self.SUMMARY_DE_CONTAINS + self.ERSTER_EINTRAG + self.DRITTER_EINTRAG,
+        )
+
+    def test_summary_robots(self):
+        self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
+
+        response = self.client.get(
+            SUMMARY_URL % self.default_language.code,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertBlogPage(response, self.default_language,
+            must_contain=('<meta name="robots" content="index,follow" />',),
+            must_not_contain=('<meta name="robots" content="noindex,nofollow" />',)
+        )
+
+    def test_tag_view_robots(self):
+        self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
+
+        url = TAG_URL = "/%s/blog/tags/%s/" % (self.default_language.code, "deutsch-tag")
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertBlogPage(response, self.default_language,
+            must_contain=('<meta name="robots" content="noindex,nofollow" />',),
+            must_not_contain=('<meta name="robots" content="index,follow" />',)
+        )
+
+#    def test_summary_en_prefered_languages(self):
+#        self._set_language_filter(BlogPrefForm.PREFERED_LANGUAGES)
+#
+#        response = self.client.get(
+#            SUMMARY_URL % self.default_language.code,
+#            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+#        )
+#        self.assertBlogPage(response, self.default_language,
+#            must_contain=self.SUMMARY_EN_CONTAINS + self.FIRST_ENTRY + self.SECOND_ENTRY,
+#            must_not_contain=self.SUMMARY_DE_CONTAINS + self.ERSTER_EINTRAG + self.DRITTER_EINTRAG,
+#        )
+#
+#        response = self.client.get(
+#            SUMMARY_URL % self.default_language.code,
+#            HTTP_ACCEPT_LANGUAGE=";".join([self.default_language.code, self.other_language]),
+#        )
+#        self.assertBlogPage(response, self.default_language,
+#            must_contain=self.SUMMARY_EN_CONTAINS + self.FIRST_ENTRY + self.SECOND_ENTRY + self.DRITTER_EINTRAG,
+#            must_not_contain=self.SUMMARY_DE_CONTAINS + self.ERSTER_EINTRAG,
+#        )
+
+'''
     def test_summary_de(self):
         response = self.client.get(
             SUMMARY_URL % self.other_language.code,
@@ -117,10 +253,57 @@ class BlogPluginAnonymousTest(BlogPluginTestCase):
         """ Anonymous user must login, to create new blog articles """
         response = self.client.get(CREATE_URL)
         self.assertRedirect(response,
-            url="http://testserver/?auth=login&next_url=/pylucid_admin/plugins/blog/new_blog_entry/",
+            url="http://testserver/?auth=login&next_url=%s" % CREATE_URL,
             status_code=302
         )
 
+    def test_login_before_edit(self):
+        """ Anonymous user must login, to edit a existing blog article """
+        url = EDIT_URL % 1
+        response = self.client.get(url)
+        self.assertRedirect(response,
+            url="http://testserver/?auth=login&next_url=%s" % url,
+            status_code=302
+        )
+
+    def test_login_before_translate(self):
+        """ Anonymous user must login, to translate a blog article """
+        url = TRANSLATE_URL % 1
+        response = self.client.get(url)
+        self.assertRedirect(response,
+            url="http://testserver/?auth=login&next_url=%s" % url,
+            status_code=302
+        )
+
+    def _test_atom_feed(self, language):
+        language_code = language.code
+        response = self.client.get(
+            "/%s/blog/feed/feed.atom" % language_code,
+            HTTP_ACCEPT_LANGUAGE=language_code,
+        )
+        self.assertAtomFeed(response, language_code)
+
+    def test_atom_feed_default_language(self):
+        self._test_atom_feed(self.default_language)
+
+    def test_atom_feed_other_language(self):
+        self._test_atom_feed(self.other_language)
+
+    def _test_rss_feed(self, language):
+        language_code = language.code
+        response = self.client.get(
+            "/%s/blog/feed/feed.rss" % language_code,
+            HTTP_ACCEPT_LANGUAGE=language_code,
+        )
+        self.assertRssFeed(response, language_code)
+
+    def test_rss_feed_default_language(self):
+        self._test_rss_feed(self.default_language)
+
+    def test_rss_feed_other_language(self):
+        self._test_rss_feed(self.other_language)
+'''
+
 
 
 class BlogPluginTest(BlogPluginTestCase):
@@ -130,7 +313,7 @@ class BlogPluginTest(BlogPluginTestCase):
     def setUp(self):
         self.client = Client() # start a new session
 
-    def test__normal_user_without_permissions(self):
+    def test_normal_user_without_permissions(self):
         """ test with insufficient permissions: normal, non-stuff user """
         self.login("normal")
         response = self.client.get(CREATE_URL)
@@ -148,7 +331,7 @@ class BlogPluginTest(BlogPluginTestCase):
         """
         self.login_with_blog_add_permissions()
         response = self.client.get(CREATE_URL)
-        self.failUnlessEqual(response.status_code, 200)
+        self.assertStatusCode(response, 200)
         self.assertResponse(response,
             must_contain=(
                 '<title>PyLucid - Create a new blog entry</title>',
@@ -185,7 +368,7 @@ class BlogPluginTest(BlogPluginTestCase):
             "sites": settings.SITE_ID,
             "tags": "django-tagging, tag1, tag2",
         })
-        blog_article_url = "http://testserver/en/blog/1/the-blog-headline/"
+        blog_article_url = "http://testserver/en/blog/%s/the-blog-headline/" % TODAY_URL_PART
         self.assertRedirect(response, url=blog_article_url, status_code=302)
 
     def test_creole_markup(self):
@@ -199,7 +382,7 @@ class BlogPluginTest(BlogPluginTestCase):
             "sites": settings.SITE_ID,
             "tags": "django-tagging, tag1, tag2",
         })
-        blog_article_url = "http://testserver/en/blog/1/the-blog-headline/"
+        blog_article_url = "http://testserver/en/blog/%s/the-blog-headline/" % TODAY_URL_PART
         self.assertRedirect(response, url=blog_article_url, status_code=302)
 
         response = self.client.get(blog_article_url)
@@ -214,7 +397,7 @@ class BlogPluginTest(BlogPluginTestCase):
     def test_markup_preview_ids(self):
         self.login_with_blog_add_permissions()
         response = self.client.get(CREATE_URL)
-        self.failUnlessEqual(response.status_code, 200)
+        self.assertStatusCode(response, 200)
         self.assertResponse(response,
             must_contain=(
                 '<fieldset id="preview_id_content">',
@@ -244,6 +427,10 @@ class BlogPluginTest(BlogPluginTestCase):
         )
 
 
+
+'''
+TODO:
+
 class BlogPluginArticleTest(BlogPluginTestCase):
     """
     Test blog plugin with existing blog articles in different languages
@@ -252,38 +439,7 @@ class BlogPluginArticleTest(BlogPluginTestCase):
         """ create some blog articles """
         super(BlogPluginArticleTest, self)._pre_setup(*args, **kwargs)
 
-        defaults = {
-            "markup": MARKUP_CREOLE,
-            "is_public": True,
-        }
 
-        self.entry_en1 = self.easy_create(BlogEntry, defaults,
-            headline="First entry in english",
-            content="1. **blog article** in //english//!",
-            language=self.default_language,
-            tags="sharedtag, first_tag, english-tag",
-        )
-
-        self.entry_en2 = self.easy_create(BlogEntry, defaults,
-            headline="Second entry in english",
-            content="2. **blog article** in //english//!",
-            language=self.default_language,
-            tags="sharedtag, second_tag, english-tag",
-        )
-
-        self.entry_de1 = self.easy_create(BlogEntry, defaults,
-            headline="Erster Eintrag in deutsch",
-            content="1. **Blog Artikel** in //deutsch//!",
-            language=self.other_language,
-            tags="sharedtag, erster_tag, deutsch-tag",
-        )
-
-        self.entry_de2 = self.easy_create(BlogEntry, defaults,
-            headline="Zweiter Eintrag in deutsch",
-            content="2. **Blog Artikel** in //deutsch//!",
-            language=self.other_language,
-            tags="sharedtag, zweiter_tag, deutsch-tag",
-        )
 
     def assertSecondArticle(self, response):
         self.assertContentLanguage(response, self.default_language)
@@ -291,11 +447,11 @@ class BlogPluginArticleTest(BlogPluginTestCase):
             must_contain=(
                 '<title>PyLucid CMS - Second entry in english</title>',
 
-                '<a href="/en/blog/2/second-entry-in-english/" class="blog_headline"'
-                ' hreflang="en">Second entry in english</a>',
+                '<a href="/en/blog/2/second-entry-in-english/" class="blog_headline" hreflang="en">',
+                'Second entry in english</a>',
 
-                '<a href="/en/blog/2/second-entry-in-english/"'
-                ' title="Article &#39;Second entry in english&#39;">Second entry in english</a>',
+                '<a href="/en/blog/2/second-entry-in-english/" title="Article &#39;Second entry in english&#39;">',
+                'Second entry in english</a>',
 
                 # english tag cloud:
                 'tag cloud', '<a href="/en/blog/tags/english-tag/" style="font-size:2em;">english-tag</a>',
@@ -311,7 +467,7 @@ class BlogPluginArticleTest(BlogPluginTestCase):
                 "All articles", "Alle Artikel",
 
                 # not the german tag cloud:
-                'Tag Cloud', '<a href="/en/blog/tags/deutsch-tag/" style="font-size:2em;">deutsch-tag</a>',
+                'Tag Cloud', '<a href="/en/blog/tags/deutsch-tag/" style="font-size:2em;">', 'deutsch-tag</a>',
             )
         )
 
@@ -386,12 +542,12 @@ class BlogPluginArticleTest(BlogPluginTestCase):
     def test_update_journal_de(self):
         # Check if listed in update journal
         response = self.client.get("/", HTTP_ACCEPT_LANGUAGE="de")
-        self.failUnlessEqual(response.status_code, 200)
+        self.assertStatusCode(response, 200)
         self.assertResponse(response,
             must_contain=(
                 '(blog entry)',
-                '<a href="/de/blog/4/zweiter-eintrag-in-deutsch/">Zweiter Eintrag in deutsch</a>',
-                '<a href="/de/blog/3/erster-eintrag-in-deutsch/">Erster Eintrag in deutsch</a>',
+                '<a href="/de/blog/4/zweiter-eintrag-in-deutsch/">', 'Zweiter Eintrag in deutsch</a>',
+                '<a href="/de/blog/3/erster-eintrag-in-deutsch/">', 'Erster Eintrag in deutsch</a>',
             ),
             must_not_contain=("Traceback", "First entry", "Second entry")
         )
@@ -399,12 +555,12 @@ class BlogPluginArticleTest(BlogPluginTestCase):
     def test_update_journal_en(self):
         # Check if listed in update journal
         response = self.client.get("/", HTTP_ACCEPT_LANGUAGE="en")
-        self.failUnlessEqual(response.status_code, 200)
+        self.assertStatusCode(response, 200)
         self.assertResponse(response,
             must_contain=(
                 '(blog entry)',
-                '<a href="/en/blog/2/second-entry-in-english/">Second entry in english</a>',
-                '<a href="/en/blog/1/first-entry-in-english/">First entry in english</a>',
+                '<a href="/en/blog/2/second-entry-in-english/">', 'Second entry in english</a>',
+                '<a href="/en/blog/1/first-entry-in-english/">', 'First entry in english</a>',
             ),
             must_not_contain=("Traceback", "Erster Eintrag", "Zweiter Eintrag")
         )
@@ -440,39 +596,38 @@ class BlogPluginArticleTest(BlogPluginTestCase):
         )
         self.assertSecondArticle(response)
 
-    def _test_atom_feed(self, language):
-        language_code = language.code
-        response = self.client.get(
-            "/%s/blog/feed/feed.atom" % language_code,
-            HTTP_ACCEPT_LANGUAGE=language_code,
+    def test_all_languages(self):
+        self.pref_form = BlogPrefForm()
+        self.pref_form["language_filter"] = BlogPrefForm.ALL_LANGUAGES
+        self.pref_form.save()
+
+        response = self.client.get("/%s/blog/" % self.default_language.code,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
         )
-        self.assertAtomFeed(response, language_code)
-
-    def test_atom_feed_default_language(self):
-        self._test_atom_feed(self.default_language)
-
-    def test_atom_feed_other_language(self):
-        self._test_atom_feed(self.other_language)
-
-    def _test_rss_feed(self, language):
-        language_code = language.code
-        response = self.client.get(
-            "/%s/blog/feed/feed.rss" % language_code,
-            HTTP_ACCEPT_LANGUAGE=language_code,
+        self.assertResponse(response,
+            must_contain=(
+                'Zweiter Eintrag in deutsch',
+                'Zweiter Eintrag in deutsch',
+                'Second entry in english',
+                'First entry in english',
+            ),
+            must_not_contain=("Traceback",)
         )
-        self.assertRssFeed(response, language_code)
-
-    def test_rss_feed_default_language(self):
-        self._test_rss_feed(self.default_language)
-
-    def test_rss_feed_other_language(self):
-        self._test_rss_feed(self.other_language)
+'''
 
 
 class BlogPluginCsrfTest(BlogPluginTestCase):
     """
     Test the Cross Site Request Forgery protection in PyLucid with the Blog Plugin
     """
+    def setUp(self):
+        super(BlogPluginCsrfTest, self).setUp()
+        settings.DEBUG = True
+
+    def tearDown(self):
+        super(BlogPluginCsrfTest, self).tearDown()
+        settings.DEBUG = False
+
     def _get_loggedin_client(self):
         csrf_client = Client(enforce_csrf_checks=True)
 
@@ -501,8 +656,6 @@ class BlogPluginCsrfTest(BlogPluginTestCase):
         )
 
     def test_create_entry_with_token(self):
-        settings.DEBUG = True
-
         csrf_client = self._get_loggedin_client()
 
         # get the current csrf token
@@ -534,7 +687,7 @@ class BlogPluginCsrfTest(BlogPluginTestCase):
             "csrfmiddlewaretoken": csrf_token
         })
 #        debug_response(response)
-        blog_article_url = "http://testserver/en/blog/1/the-blog-headline/"
+        blog_article_url = "http://testserver/en/blog/%s/the-blog-headline/" % TODAY_URL_PART
         self.assertRedirect(response, url=blog_article_url, status_code=302)
 
 
@@ -546,10 +699,12 @@ if __name__ == "__main__":
 
     tests = __file__
 #    tests = "pylucid_plugins.blog.tests.BlogPluginCsrfTest"
+#    tests = "pylucid_plugins.blog.tests.BlogPluginAnonymousTest"
+#    tests = "pylucid_plugins.blog.tests.BlogLanguageFilterTest"
 #    tests = "pylucid_plugins.blog.tests.BlogPluginTest"
 #    tests = "pylucid_plugins.blog.tests.BlogPluginTest.test_create_csrf_check"
 #    tests = "pylucid_plugins.blog.tests.BlogPluginTest.test_creole_markup"
-#    tests = "pylucid_plugins.blog.tests.BlogPluginTest.test_markup_preview_ids"
+#    tests = "pylucid_plugins.blog.tests.BlogPluginArticleTest"
 
     management.call_command('test', tests,
         verbosity=2,
