@@ -78,7 +78,7 @@ class LexiconPluginTestCase(basetest.BaseLanguageTestCase):
     )
 
     def assertLexiconPage(self, response, must_contain):
-        self.failUnlessEqual(response.status_code, 200)
+        self.assertStatusCode(response, 200)
         self.assertResponse(response, must_contain=must_contain,
             must_not_contain=("Traceback", "XXX INVALID TEMPLATE STRING")
         )
@@ -150,7 +150,7 @@ class LexiconPluginTest1(LexiconPluginTestCase):
         )
 
     def test_get_view(self):
-        response = self.client.get("/?lexicon=PyLucid CMS")
+        response = self.client.get("/en/welcome/?lexicon=PyLucid CMS")
         self.assertResponse(response,
             must_contain=(
                 'PyLucid CMS',
@@ -337,5 +337,5 @@ if __name__ == "__main__":
 
     management.call_command('test', tests,
         verbosity=2,
-        failfast=True
+#        failfast=True
     )
